@@ -13,9 +13,9 @@ use Perinci::Sub::Util qw(err gen_modified_sub);
 require Exporter;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-13'; # DATE
+our $DATE = '2025-03-29'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.352'; # VERSION
+our $VERSION = '0.353'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = (
@@ -48,7 +48,10 @@ $SPEC{':package'} = {
 my @fixed_holidays = (
     my $newyear = {
         day        =>  1, month =>  1,
-        ind_name   => "Tahun Baru",
+        ind_name   => sub {
+            my $opts = shift;
+            "Tahun Baru " . $opts->{year} . " Masehi";
+        },
         eng_name   => "New Year",
         tags       => [qw/international/],
         fixed_date => 1,
@@ -100,10 +103,13 @@ sub _add_original_date {
     }
 }
 
+our $year;
+
 sub _h_chnewyear {
     my ($r, $opts) = @_;
+    $opts //= {};
     $r->{ind_name}    = "Tahun Baru Imlek".
-        ($opts->{hyear} ? " $opts->{hyear}":"");
+        ($opts->{hyear} ? " $opts->{hyear}" . ($year && $year >= 2024 ? " Kongzili" : ""):"");
     $r->{eng_name}    = "Chinese New Year".
         ($opts->{hyear} ? " $opts->{hyear}":"");
     _add_original_date($r, $opts);
@@ -156,7 +162,9 @@ sub _h_goodfri {
 # since 2024
 sub _h_easter {
     my ($r, $opts) = @_;
-    $r->{ind_name}    = "Paskah";
+    $opts //= {};
+    $r->{ind_name}    = $year && $year >= 2025 ?
+        "Kebangkitan Yesus Kristus (Paskah)" : "Hari Paskah";
     $r->{eng_name}    = "Easter";
     _add_original_date($r, $opts);
     $r->{ind_aliases} = [];
@@ -182,7 +190,9 @@ sub _h_vesakha {
 
 sub _h_ascension {
     my ($r, $opts) = @_;
-    $r->{ind_name}    = "Kenaikan Isa Al-Masih";
+    $opts //= {};
+    $r->{ind_name}    = $year && $year >= 2024 ?
+        "Kenaikan Yesus Kristus" : "Kenaikan Isa Al-Masih";
     $r->{eng_name}    = "Ascension Day";
     _add_original_date($r, $opts);
     $r->{ind_aliases} = [];
@@ -1288,14 +1298,14 @@ our %year_holidays;
 {
     # 2024 holidays
     my ($chnewyear2024, $nyepi2024, $eidulf2024, $ascension2024, $eidula2024, $vesakha2024, $christmas);
-    $year_holidays{2024} = [
+    local $year = 2024;
+    $year_holidays{$year} = [
         # - new year
         _h_isramiraj ({_expand_dm("08-02")}, {hyear=>1445}),
         ($chnewyear2024 = _h_chnewyear ({_expand_dm("10-02")}, {hyear=>2575})),
         _h_pelection ({_expand_dm("14-02")}, {}),
         ($nyepi2024 = _h_nyepi     ({_expand_dm("11-03")}, {hyear=>1946})),
         _h_goodfri   ({_expand_dm("29-03")}),
-        _h_goodfri   ({_expand_dm("29-03")}),
         _h_easter    ({_expand_dm("31-03")}),
         ($eidulf2024 = _h_eidulf    ({_expand_dm("10-04")}, {hyear=>1445, day=>1})),
         _h_eidulf    ({_expand_dm("11-04")}, {hyear=>1445, day=>2}),
@@ -1310,7 +1320,7 @@ our %year_holidays;
         # - christmas
     ];
 
-    push @{ $year_holidays{2024} }, (
+    push @{ $year_holidays{$year} }, (
         _jointlv     ({_expand_dm("09-02")}, {holiday=>$chnewyear2024}),
         _jointlv     ({_expand_dm("12-03")}, {holiday=>$nyepi2024}),
         _jointlv     ({_expand_dm("08-04")}, {holiday=>$eidulf2024}),
@@ -1324,10 +1334,46 @@ our %year_holidays;
     );
 }
 
+# decreed oct 14, 2024 (SKB No 1017/2024, 2/2024, 2/2024)
+#
+# ref:
+# - https://www.kemenkopmk.go.id/sites/default/files/pengumuman/2024-10/SKB%203%20Menteri%20Libur%20Nasional%20dan%20Cuti%20Bersama%20Tahun%202025.pdf
 {
     # 2025 holidays
-    #_h_jrelection({_expand_dm("09-12")}, {decree_date => "2025-11-xx"}), # keppres xx/2025, surat edaran menaker xxx.../2020 (2020-12-xx)
-    1;
+    my ($chnewyear2025, $nyepi2025, $eidulf2025, $ascension2025, $eidula2025, $vesakha2025, $christmas);
+    local $year = 2025;
+    $year_holidays{$year} = [
+        # - new year
+        _h_isramiraj ({_expand_dm("27-01")}, {hyear=>1446}),
+        ($chnewyear2025 = _h_chnewyear ({_expand_dm("29-01")}, {hyear=>2576})),
+        ($nyepi2025 = _h_nyepi({_expand_dm("29-03")}, {hyear=>1947})),
+        ($eidulf2025 = _h_eidulf({_expand_dm("31-03")}, {hyear=>1446, day=>1})),
+        _h_eidulf    ({_expand_dm("01-04")}, {hyear=>1446, day=>2}),
+        _h_goodfri   ({_expand_dm("18-04")}),
+        _h_easter    ({_expand_dm("20-04")}),
+        # - labor day
+        _h_vesakha   ({_expand_dm("12-05")}, {hyear=>2569}),
+        ($ascension2025 = _h_ascension({_expand_dm("29-05")})),
+        # - pancasila day
+        ($eidula2025 = _h_eidula({_expand_dm("06-06")}, {hyear=>1446})),
+        _h_hijra     ({_expand_dm("27-06")}, {hyear=>1447}),
+        # - independence day
+        _h_mawlid({_expand_dm("05-09")}, {hyear=>1447}),
+        # - christmas
+    ];
+
+    push @{ $year_holidays{$year} }, (
+        _jointlv     ({_expand_dm("28-01")}, {holiday=>$chnewyear2025}),
+        _jointlv     ({_expand_dm("28-03")}, {holiday=>$nyepi2025}),
+        _jointlv     ({_expand_dm("02-04")}, {holiday=>$eidulf2025}),
+        _jointlv     ({_expand_dm("03-04")}, {holiday=>$eidulf2025}),
+        _jointlv     ({_expand_dm("04-04")}, {holiday=>$eidulf2025}),
+        _jointlv     ({_expand_dm("07-04")}, {holiday=>$eidulf2025}),
+        _jointlv     ({_expand_dm("13-05")}, {holiday=>$vesakha2025}),
+        _jointlv     ({_expand_dm("30-05")}, {holiday=>$ascension2025}),
+        _jointlv     ({_expand_dm("09-06")}, {holiday=>$eidula2025}),
+        _jointlv     ({_expand_dm("26-12")}, {holiday=>$christmas}),
+    );
 }
 
 {
@@ -1354,6 +1400,9 @@ for my $year ($min_year .. $max_year) {
         next if $h0->{year_start} && $year < $h0->{year_start};
         next if $h0->{year_en}    && $year > $h0->{year_end};
         my $h = clone $h0;
+        if (ref $h->{ind_name} eq 'CODE') {
+            $h->{ind_name} = $h->{ind_name}->({year=>$year});
+        }
         push @{$h->{tags}}, "fixed-date";
         $h->{is_holiday}     = 1;
         $h->{is_joint_leave} = 0;
@@ -1717,7 +1766,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.352 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2023-11-13.
+This document describes version 0.353 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2025-03-29.
 
 =head1 SYNOPSIS
 
@@ -1803,7 +1852,7 @@ This module provides functions to list Indonesian holidays. There is a
 command-line script interface for this module: L<list-idn-holidays> and a few
 others distributed in L<App::IndonesianHolidayUtils> distribution.
 
-Calendar years supported: 1990-2024.
+Calendar years supported: 1990-2025.
 
 Note: Note that sometimes the holiday (as set by law) falls at a different date
 than the actual religious commemoration date. When you use the C<detail> option,
@@ -1847,7 +1896,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 1990 to 2024
+Contains data from years 1990 to 2025
 
 This function is not exported by default, but exportable.
 
@@ -1982,7 +2031,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 1990 to 2024
+Contains data from years 1990 to 2025
 
 This function is not exported by default, but exportable.
 
@@ -2040,7 +2089,7 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 1990 to 2024
+Contains data from years 1990 to 2025
 
 This function is not exported by default, but exportable.
 
@@ -2619,7 +2668,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 1990 to 2024
+Contains data from years 1990 to 2025
 
 This function is not exported by default, but exportable.
 
@@ -2775,7 +2824,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
